@@ -85,32 +85,27 @@ class AutoModRuleAction:
     __slots__ = ('type', 'channel_id', 'duration', 'custom_message')
 
     @overload
-    def __init__(self, *, channel_id: int = ...) -> None:
-        ...
+    def __init__(self, *, channel_id: int = ...) -> None: ...
 
     @overload
-    def __init__(self, *, type: Literal[AutoModRuleActionType.send_alert_message], channel_id: int = ...) -> None:
-        ...
+    def __init__(self, *, type: Literal[AutoModRuleActionType.send_alert_message], channel_id: int = ...) -> None: ...
 
     @overload
-    def __init__(self, *, duration: datetime.timedelta = ...) -> None:
-        ...
+    def __init__(self, *, duration: datetime.timedelta = ...) -> None: ...
 
     @overload
-    def __init__(self, *, type: Literal[AutoModRuleActionType.timeout], duration: datetime.timedelta = ...) -> None:
-        ...
+    def __init__(self, *, type: Literal[AutoModRuleActionType.timeout], duration: datetime.timedelta = ...) -> None: ...
 
     @overload
-    def __init__(self, *, custom_message: str = ...) -> None:
-        ...
+    def __init__(self, *, custom_message: str = ...) -> None: ...
 
     @overload
-    def __init__(self, *, type: Literal[AutoModRuleActionType.block_message]) -> None:
-        ...
+    def __init__(self, *, type: Literal[AutoModRuleActionType.block_message]) -> None: ...
 
     @overload
-    def __init__(self, *, type: Literal[AutoModRuleActionType.block_message], custom_message: Optional[str] = ...) -> None:
-        ...
+    def __init__(
+        self, *, type: Literal[AutoModRuleActionType.block_message], custom_message: Optional[str] = ...
+    ) -> None: ...
 
     @overload
     def __init__(
@@ -120,8 +115,7 @@ class AutoModRuleAction:
         channel_id: Optional[int] = ...,
         duration: Optional[datetime.timedelta] = ...,
         custom_message: Optional[str] = ...,
-    ) -> None:
-        ...
+    ) -> None: ...
 
     def __init__(
         self,
