@@ -131,6 +131,7 @@ class Component:
     - :class:`FileComponent`
     - :class:`SeparatorComponent`
     - :class:`Container`
+    - :class:`LabelComponent`
 
     This class is abstract and cannot be instantiated.
 
@@ -396,6 +397,7 @@ class SelectMenu(Component):
             'min_values': self.min_values,
             'max_values': self.max_values,
             'disabled': self.disabled,
+            'required': self.required,
         }
         if self.id is not None:
             payload['id'] = self.id
@@ -1354,11 +1356,11 @@ class LabelComponent(Component):
     __slots__ = (
         'label',
         'description',
-        'commponent',
+        'component',
         'id',
     )
 
-    __repr_info__ = ('label', 'description', 'commponent', 'id,')
+    __repr_info__ = ('label', 'description', 'component')
 
     def __init__(self, data: LabelComponentPayload, state: Optional[ConnectionState]) -> None:
         self.component: Component = _component_factory(data['component'], state)  # type: ignore
