@@ -167,6 +167,12 @@ class PartialEmoji(_EmojiTag, AssetMixin):
             return {'emoji_id': self.id, 'emoji_name': None}
         return {'emoji_id': None, 'emoji_name': self.name}
 
+    def _to_onboarding_prompt_option_payload(self) -> Dict[str, Any]:
+        if self.id is not None:
+            return {'emoji_id': self.id, 'emoji_name': self.name, 'emoji_animated': self.animated}
+
+        return {'emoji_name': self.name}
+
     @classmethod
     def with_state(
         cls,
