@@ -33,11 +33,12 @@ from .integration import IntegrationExpireBehavior, PartialIntegration
 from .user import User
 from .scheduled_event import EntityType, EventStatus, GuildScheduledEvent
 from .snowflake import Snowflake
-from .role import Role
+from .role import Role, RoleColours
 from .channel import ChannelType, DefaultReaction, PrivacyLevel, VideoQualityMode, PermissionOverwrite, ForumTag
 from .threads import Thread
 from .command import ApplicationCommand, ApplicationCommandPermissions
 from .automod import AutoModerationTriggerMetadata
+from .onboarding import PromptOption, Prompt
 
 AuditLogEvent = Literal[
     1,
@@ -88,14 +89,25 @@ AuditLogEvent = Literal[
     111,
     112,
     121,
+    130,
+    131,
+    132,
     140,
     141,
     142,
     143,
     144,
     145,
+    146,
     150,
     151,
+    163,
+    164,
+    165,
+    166,
+    167,
+    190,
+    191,
 ]
 
 
@@ -112,6 +124,8 @@ class _AuditLogChange_Str(TypedDict):
         'permissions',
         'tags',
         'unicode_emoji',
+        'emoji_name',
+        'title',
     ]
     new_value: str
     old_value: str
@@ -136,6 +150,8 @@ class _AuditLogChange_Snowflake(TypedDict):
         'channel_id',
         'inviter_id',
         'guild_id',
+        'user_id',
+        'sound_id',
     ]
     new_value: Snowflake
     old_value: Snowflake
@@ -157,6 +173,10 @@ class _AuditLogChange_Bool(TypedDict):
         'available',
         'archived',
         'locked',
+        'enabled',
+        'single_select',
+        'required',
+        'in_onboarding',
     ]
     new_value: bool
     old_value: bool
@@ -183,6 +203,12 @@ class _AuditLogChange_Int(TypedDict):
     old_value: int
 
 
+class _AuditLogChange_Float(TypedDict):
+    key: Literal['volume']
+    new_value: float
+    old_value: float
+
+
 class _AuditLogChange_ListRole(TypedDict):
     key: Literal['$add', '$remove']
     new_value: List[Role]
@@ -261,8 +287,8 @@ class _AuditLogChange_AppCommandPermissions(TypedDict):
     old_value: ApplicationCommandPermissions
 
 
-class _AuditLogChange_AppliedTags(TypedDict):
-    key: Literal['applied_tags']
+class _AuditLogChange_SnowflakeList(TypedDict):
+    key: Literal['applied_tags', 'default_channel_ids']
     new_value: List[Snowflake]
     old_value: List[Snowflake]
 
@@ -285,11 +311,30 @@ class _AuditLogChange_TriggerMetadata(TypedDict):
     old_value: Optional[AutoModerationTriggerMetadata]
 
 
+class _AuditLogChange_Prompts(TypedDict):
+    key: Literal['prompts']
+    new_value: List[Prompt]
+    old_value: List[Prompt]
+
+
+class _AuditLogChange_Options(TypedDict):
+    key: Literal['options']
+    new_value: List[PromptOption]
+    old_value: List[PromptOption]
+
+
+class _AuditLogChange_RoleColours(TypedDict):
+    key: Literal['colors']
+    new_value: RoleColours
+    old_value: RoleColours
+
+
 AuditLogChange = Union[
     _AuditLogChange_Str,
     _AuditLogChange_AssetHash,
     _AuditLogChange_Snowflake,
     _AuditLogChange_Int,
+    _AuditLogChange_Float,
     _AuditLogChange_Bool,
     _AuditLogChange_ListRole,
     _AuditLogChange_MFALevel,
@@ -304,10 +349,13 @@ AuditLogChange = Union[
     _AuditLogChange_Status,
     _AuditLogChange_EntityType,
     _AuditLogChange_AppCommandPermissions,
-    _AuditLogChange_AppliedTags,
+    _AuditLogChange_SnowflakeList,
     _AuditLogChange_AvailableTags,
     _AuditLogChange_DefaultReactionEmoji,
     _AuditLogChange_TriggerMetadata,
+    _AuditLogChange_Prompts,
+    _AuditLogChange_Options,
+    _AuditLogChange_RoleColours,
 ]
 
 
