@@ -38,28 +38,14 @@ class EmbedField(TypedDict):
     inline: NotRequired[bool]
 
 
-class EmbedThumbnail(TypedDict, total=False):
+class EmbedMedia(TypedDict, total=False):
     url: Required[str]
     proxy_url: str
     height: int
     width: int
-
-
-class EmbedVideo(TypedDict, total=False):
-    url: str
-    proxy_url: str
-    height: int
-    width: int
     flags: int
 
 
-class EmbedImage(TypedDict, total=False):
-    url: Required[str]
-    proxy_url: str
-    height: int
-    width: int
-
-
 class EmbedProvider(TypedDict, total=False):
     name: str
     url: str
@@ -83,9 +69,9 @@ class Embed(TypedDict, total=False):
     timestamp: str
     color: int
     footer: EmbedFooter
-    image: EmbedImage
-    thumbnail: EmbedThumbnail
-    video: EmbedVideo
+    image: EmbedMedia
+    thumbnail: EmbedMedia
+    video: EmbedMedia
     provider: EmbedProvider
     author: EmbedAuthor
     fields: List[EmbedField]
