@@ -78,6 +78,7 @@ if TYPE_CHECKING:
     from ..types.interactions import SelectMessageComponentInteractionData
     from ..app_commands import AppCommandChannel, AppCommandThread
     from ..interactions import Interaction
+    from ..app_commands.namespace import ResolveKey
 
     ValidSelectType: TypeAlias = Literal[
         ComponentType.string_select,
@@ -356,16 +357,34 @@ class BaseSelect(Item[V]):
     def _refresh_component(self, component: SelectMenu) -> None:
         self._underlying = component
 
-    def _refresh_state(self, interaction: Interaction, data: SelectMessageComponentInteractionData) -> None:
+    def _handle_submit(
+        self, interaction: Interaction, data: SelectMessageComponentInteractionData, resolved: Dict[ResolveKey, Any]
+    ) -> None:
+        payload: List[PossibleValue]
+        values = selected_values.get({})
+        string_values = data.get('values', [])
+        payload = [v for k, v in resolved.items() if k.id in string_values]
+        if not payload:
+            payload = list(string_values)
+
+        self._values = values[self.custom_id] = payload
+        selected_values.set(values)
+
+    def _refresh_state(
+        self,
+        interaction: Interaction,
+        data: SelectMessageComponentInteractionData,
+    ) -> None:
         values = selected_values.get({})
         payload: List[PossibleValue]
         try:
             resolved = Namespace._get_resolved_items(
-                interaction, data['resolved']  # pyright: ignore[reportTypedDictNotRequiredAccess]
+                interaction,
+                data['resolved'],  # pyright: ignore[reportTypedDictNotRequiredAccess]
             )
             payload = list(resolved.values())
         except KeyError:
-            payload = data.get("values", [])  # type: ignore
+            payload = list(data.get('values', []))
 
         self._values = values[self.custom_id] = payload
         selected_values.set(values)
@@ -579,6 +598,10 @@ class UserSelect(BaseSelect[V]):
         Defaults to 1 and must be between 1 and 25.
     disabled: :class:`bool`
         Whether the select is disabled or not.
+    required: :class:`bool`
+        Whether the select is required. Only applicable within modals.
+
+        .. versionadded:: 2.6
     default_values: Sequence[:class:`~discord.abc.Snowflake`]
         A list of objects representing the users that should be selected by default.
         Number of items must be in range of ``min_values`` and ``max_values``.
@@ -610,6 +633,7 @@ class UserSelect(BaseSelect[V]):
         min_values: int = 1,
         max_values: int = 1,
         disabled: bool = False,
+        required: bool = False,
         row: Optional[int] = None,
         default_values: Sequence[ValidDefaultValues] = MISSING,
         id: Optional[int] = None,
@@ -621,6 +645,7 @@ class UserSelect(BaseSelect[V]):
             min_values=min_values,
             max_values=max_values,
             disabled=disabled,
+            required=required,
             row=row,
             default_values=_handle_select_defaults(default_values, self.type),
             id=id,
@@ -681,6 +706,10 @@ class RoleSelect(BaseSelect[V]):
         Defaults to 1 and must be between 1 and 25.
     disabled: :class:`bool`
         Whether the select is disabled or not.
+    required: :class:`bool`
+        Whether the select is required. Only applicable within modals.
+
+        .. versionadded:: 2.6
     default_values: Sequence[:class:`~discord.abc.Snowflake`]
         A list of objects representing the roles that should be selected by default.
         Number of items must be in range of ``min_values`` and ``max_values``.
@@ -712,6 +741,7 @@ class RoleSelect(BaseSelect[V]):
         min_values: int = 1,
         max_values: int = 1,
         disabled: bool = False,
+        required: bool = False,
         row: Optional[int] = None,
         default_values: Sequence[ValidDefaultValues] = MISSING,
         id: Optional[int] = None,
@@ -723,6 +753,7 @@ class RoleSelect(BaseSelect[V]):
             min_values=min_values,
             max_values=max_values,
             disabled=disabled,
+            required=required,
             row=row,
             default_values=_handle_select_defaults(default_values, self.type),
             id=id,
@@ -778,6 +809,10 @@ class MentionableSelect(BaseSelect[V]):
         Defaults to 1 and must be between 1 and 25.
     disabled: :class:`bool`
         Whether the select is disabled or not.
+    required: :class:`bool`
+        Whether the select is required. Only applicable within modals.
+
+        .. versionadded:: 2.6
     default_values: Sequence[:class:`~discord.abc.Snowflake`]
         A list of objects representing the users/roles that should be selected by default.
         if :class:`.Object` is passed, then the type must be specified in the constructor.
@@ -810,6 +845,7 @@ class MentionableSelect(BaseSelect[V]):
         min_values: int = 1,
         max_values: int = 1,
         disabled: bool = False,
+        required: bool = False,
         row: Optional[int] = None,
         default_values: Sequence[ValidDefaultValues] = MISSING,
         id: Optional[int] = None,
@@ -821,6 +857,7 @@ class MentionableSelect(BaseSelect[V]):
             min_values=min_values,
             max_values=max_values,
             disabled=disabled,
+            required=required,
             row=row,
             default_values=_handle_select_defaults(default_values, self.type),
             id=id,
@@ -883,6 +920,10 @@ class ChannelSelect(BaseSelect[V]):
         Defaults to 1 and must be between 1 and 25.
     disabled: :class:`bool`
         Whether the select is disabled or not.
+    required: :class:`bool`
+        Whether the select is required. Only applicable within modals.
+
+        .. versionadded:: 2.6
     default_values: Sequence[:class:`~discord.abc.Snowflake`]
         A list of objects representing the channels that should be selected by default.
         Number of items must be in range of ``min_values`` and ``max_values``.
@@ -918,6 +959,7 @@ class ChannelSelect(BaseSelect[V]):
         min_values: int = 1,
         max_values: int = 1,
         disabled: bool = False,
+        required: bool = False,
         row: Optional[int] = None,
         default_values: Sequence[ValidDefaultValues] = MISSING,
         id: Optional[int] = None,
@@ -929,6 +971,7 @@ class ChannelSelect(BaseSelect[V]):
             min_values=min_values,
             max_values=max_values,
             disabled=disabled,
+            required=required,
             row=row,
             channel_types=channel_types,
             default_values=_handle_select_defaults(default_values, self.type),
@@ -985,8 +1028,7 @@ def select(
     disabled: bool = ...,
     row: Optional[int] = ...,
     id: Optional[int] = ...,
-) -> SelectCallbackDecorator[S, SelectT]:
-    ...
+) -> SelectCallbackDecorator[S, SelectT]: ...
 
 
 @overload
@@ -1003,8 +1045,7 @@ def select(
     default_values: Sequence[ValidDefaultValues] = ...,
     row: Optional[int] = ...,
     id: Optional[int] = ...,
-) -> SelectCallbackDecorator[S, UserSelectT]:
-    ...
+) -> SelectCallbackDecorator[S, UserSelectT]: ...
 
 
 @overload
@@ -1021,8 +1062,7 @@ def select(
     default_values: Sequence[ValidDefaultValues] = ...,
     row: Optional[int] = ...,
     id: Optional[int] = ...,
-) -> SelectCallbackDecorator[S, RoleSelectT]:
-    ...
+) -> SelectCallbackDecorator[S, RoleSelectT]: ...
 
 
 @overload
@@ -1039,8 +1079,7 @@ def select(
     default_values: Sequence[ValidDefaultValues] = ...,
     row: Optional[int] = ...,
     id: Optional[int] = ...,
-) -> SelectCallbackDecorator[S, ChannelSelectT]:
-    ...
+) -> SelectCallbackDecorator[S, ChannelSelectT]: ...
 
 
 @overload
@@ -1057,8 +1096,7 @@ def select(
     default_values: Sequence[ValidDefaultValues] = ...,
     row: Optional[int] = ...,
     id: Optional[int] = ...,
-) -> SelectCallbackDecorator[S, MentionableSelectT]:
-    ...
+) -> SelectCallbackDecorator[S, MentionableSelectT]: ...
 
 
 def select(
