@@ -20,45 +20,29 @@ AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 DEALINGS IN THE SOFTWARE.
-
-
-Some documentation to refer to:
-
-- Our main web socket (mWS) sends opcode 4 with a guild ID and channel ID.
-- The mWS receives VOICE_STATE_UPDATE and VOICE_SERVER_UPDATE.
-- We pull the session_id from VOICE_STATE_UPDATE.
-- We pull the token, endpoint and server_id from VOICE_SERVER_UPDATE.
-- Then we initiate the voice web socket (vWS) pointing to the endpoint.
-- We send opcode 0 with the user_id, server_id, session_id and token using the vWS.
-- The vWS sends back opcode 2 with an ssrc, port, modes(array) and heartbeat_interval.
-- We send a UDP discovery packet to endpoint:port and receive our IP and our port in LE.
-- Then we send our IP and port via vWS with opcode 1.
-- When that's all done, we receive opcode 4 from the vWS.
-- Finally we can transmit data to endpoint:port.
 """
 
 from __future__ import annotations
 
 import asyncio
-import socket
 import logging
 import struct
-import threading
 from typing import Any, Callable, List, Optional, TYPE_CHECKING, Tuple, Union
 
-from . import opus, utils
-from .backoff import ExponentialBackoff
+from . import opus
 from .gateway import *
-from .errors import ClientException, ConnectionClosed
+from .errors import ClientException
 from .player import AudioPlayer, AudioSource
 from .utils import MISSING
+from .voice_state import VoiceConnectionState
 
 if TYPE_CHECKING:
+    from .gateway import DiscordVoiceWebSocket
     from .client import Client
     from .guild import Guild
     from .state import ConnectionState
     from .user import ClientUser
-    from .opus import Encoder
+    from .opus import Encoder, APPLICATION_CTL, BAND_CTL, SIGNAL_CTL
     from .channel import StageChannel, VoiceChannel
     from . import abc
 
@@ -121,6 +105,10 @@ class VoiceProtocol:
         An abstract method that is called when the client's voice state
         has changed. This corresponds to ``VOICE_STATE_UPDATE``.
 
+        .. warning::
+
+            This method is not the same as the event. See: :func:`on_voice_state_update`
+
         Parameters
         ------------
         data: :class:`dict`
@@ -137,7 +125,7 @@ class VoiceProtocol:
         Parameters
         ------------
         data: :class:`dict`
-            The raw :ddocs:`voice server update payload <topics/gateway#voice-server-update>`.
+            The raw :ddocs:`voice server update payload <topics/gateway-events#voice-server-update>`.
         """
         raise NotImplementedError
 
@@ -226,45 +214,29 @@ class VoiceClient(VoiceProtocol):
     """
 
     channel: VocalGuildChannel
-    endpoint_ip: str
-    voice_port: int
-    ip: str
-    port: int
-    secret_key: List[int]
-    ssrc: int
 
     def __init__(self, client: Client, channel: abc.Connectable) -> None:
         if not has_nacl:
-            raise RuntimeError("PyNaCl library needed in order to use voice")
+            raise RuntimeError('PyNaCl library needed in order to use voice')
 
         super().__init__(client, channel)
         state = client._connection
-        self.token: str = MISSING
         self.server_id: int = MISSING
         self.socket = MISSING
         self.loop: asyncio.AbstractEventLoop = state.loop
         self._state: ConnectionState = state
-        # this will be used in the AudioPlayer thread
-        self._connected: threading.Event = threading.Event()
 
-        self._handshaking: bool = False
-        self._potentially_reconnecting: bool = False
-        self._voice_state_complete: asyncio.Event = asyncio.Event()
-        self._voice_server_complete: asyncio.Event = asyncio.Event()
-
-        self.mode: str = MISSING
-        self._connections: int = 0
         self.sequence: int = 0
         self.timestamp: int = 0
-        self.timeout: float = 0
-        self._runner: asyncio.Task = MISSING
         self._player: Optional[AudioPlayer] = None
         self.encoder: Encoder = MISSING
-        self._lite_nonce: int = 0
-        self.ws: DiscordVoiceWebSocket = MISSING
+        self._incr_nonce: int = 0
+
+        self._connection: VoiceConnectionState = self.create_connection_state()
 
     warn_nacl: bool = not has_nacl
     supported_modes: Tuple[SupportedModes, ...] = (
+        'aead_xchacha20_poly1305_rtpsize',
         'xsalsa20_poly1305_lite',
         'xsalsa20_poly1305_suffix',
         'xsalsa20_poly1305',
@@ -280,6 +252,38 @@ class VoiceClient(VoiceProtocol):
         """:class:`ClientUser`: The user connected to voice (i.e. ourselves)."""
         return self._state.user  # type: ignore
 
+    @property
+    def session_id(self) -> Optional[str]:
+        return self._connection.session_id
+
+    @property
+    def token(self) -> Optional[str]:
+        return self._connection.token
+
+    @property
+    def endpoint(self) -> Optional[str]:
+        return self._connection.endpoint
+
+    @property
+    def ssrc(self) -> int:
+        return self._connection.ssrc
+
+    @property
+    def mode(self) -> SupportedModes:
+        return self._connection.mode
+
+    @property
+    def secret_key(self) -> List[int]:
+        return self._connection.secret_key
+
+    @property
+    def ws(self) -> DiscordVoiceWebSocket:
+        return self._connection.ws
+
+    @property
+    def timeout(self) -> float:
+        return self._connection.timeout
+
     def checked_add(self, attr: str, value: int, limit: int) -> None:
         val = getattr(self, attr)
         if val + value > limit:
@@ -289,149 +293,23 @@ class VoiceClient(VoiceProtocol):
 
     # connection related
 
-    async def on_voice_state_update(self, data: GuildVoiceStatePayload) -> None:
-        self.session_id: str = data['session_id']
-        channel_id = data['channel_id']
+    def create_connection_state(self) -> VoiceConnectionState:
+        return VoiceConnectionState(self)
 
-        if not self._handshaking or self._potentially_reconnecting:
-            # If we're done handshaking then we just need to update ourselves
-            # If we're potentially reconnecting due to a 4014, then we need to differentiate
-            # a channel move and an actual force disconnect
-            if channel_id is None:
-                # We're being disconnected so cleanup
-                await self.disconnect()
-            else:
-                self.channel = channel_id and self.guild.get_channel(int(channel_id))  # type: ignore
-        else:
-            self._voice_state_complete.set()
+    async def on_voice_state_update(self, data: GuildVoiceStatePayload) -> None:
+        await self._connection.voice_state_update(data)
 
     async def on_voice_server_update(self, data: VoiceServerUpdatePayload) -> None:
-        if self._voice_server_complete.is_set():
-            _log.warning('Ignoring extraneous voice server update.')
-            return
-
-        self.token = data['token']
-        self.server_id = int(data['guild_id'])
-        endpoint = data.get('endpoint')
-
-        if endpoint is None or self.token is None:
-            _log.warning(
-                'Awaiting endpoint... This requires waiting. '
-                'If timeout occurred considering raising the timeout and reconnecting.'
-            )
-            return
-
-        self.endpoint, _, _ = endpoint.rpartition(':')
-        if self.endpoint.startswith('wss://'):
-            # Just in case, strip it off since we're going to add it later
-            self.endpoint: str = self.endpoint[6:]
-
-        # This gets set later
-        self.endpoint_ip = MISSING
-
-        self.socket: socket.socket = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-        self.socket.setblocking(False)
-
-        if not self._handshaking:
-            # If we're not handshaking then we need to terminate our previous connection in the websocket
-            await self.ws.close(4000)
-            return
-
-        self._voice_server_complete.set()
-
-    async def voice_connect(self, self_deaf: bool = False, self_mute: bool = False) -> None:
-        await self.channel.guild.change_voice_state(channel=self.channel, self_deaf=self_deaf, self_mute=self_mute)
-
-    async def voice_disconnect(self) -> None:
-        _log.info('The voice handshake is being terminated for Channel ID %s (Guild ID %s)', self.channel.id, self.guild.id)
-        await self.channel.guild.change_voice_state(channel=None)
-
-    def prepare_handshake(self) -> None:
-        self._voice_state_complete.clear()
-        self._voice_server_complete.clear()
-        self._handshaking = True
-        _log.info('Starting voice handshake... (connection attempt %d)', self._connections + 1)
-        self._connections += 1
-
-    def finish_handshake(self) -> None:
-        _log.info('Voice handshake complete. Endpoint found %s', self.endpoint)
-        self._handshaking = False
-        self._voice_server_complete.clear()
-        self._voice_state_complete.clear()
-
-    async def connect_websocket(self) -> DiscordVoiceWebSocket:
-        ws = await DiscordVoiceWebSocket.from_client(self)
-        self._connected.clear()
-        while ws.secret_key is None:
-            await ws.poll_event()
-        self._connected.set()
-        return ws
+        await self._connection.voice_server_update(data)
 
     async def connect(self, *, reconnect: bool, timeout: float, self_deaf: bool = False, self_mute: bool = False) -> None:
-        _log.info('Connecting to voice...')
-        self.timeout = timeout
+        await self._connection.connect(
+            reconnect=reconnect, timeout=timeout, self_deaf=self_deaf, self_mute=self_mute, resume=False
+        )
 
-        for i in range(5):
-            self.prepare_handshake()
-
-            # This has to be created before we start the flow.
-            futures = [
-                self._voice_state_complete.wait(),
-                self._voice_server_complete.wait(),
-            ]
-
-            # Start the connection flow
-            await self.voice_connect(self_deaf=self_deaf, self_mute=self_mute)
-
-            try:
-                await utils.sane_wait_for(futures, timeout=timeout)
-            except asyncio.TimeoutError:
-                await self.disconnect(force=True)
-                raise
-
-            self.finish_handshake()
-
-            try:
-                self.ws = await self.connect_websocket()
-                break
-            except (ConnectionClosed, asyncio.TimeoutError):
-                if reconnect:
-                    _log.exception('Failed to connect to voice... Retrying...')
-                    await asyncio.sleep(1 + i * 2.0)
-                    await self.voice_disconnect()
-                    continue
-                else:
-                    raise
-
-        if self._runner is MISSING:
-            self._runner = self.client.loop.create_task(self.poll_voice_ws(reconnect))
-
-    async def potential_reconnect(self) -> bool:
-        # Attempt to stop the player thread from playing early
-        self._connected.clear()
-        self.prepare_handshake()
-        self._potentially_reconnecting = True
-        try:
-            # We only care about VOICE_SERVER_UPDATE since VOICE_STATE_UPDATE can come before we get disconnected
-            await asyncio.wait_for(self._voice_server_complete.wait(), timeout=self.timeout)
-        except asyncio.TimeoutError:
-            self._potentially_reconnecting = False
-            await self.disconnect(force=True)
-            return False
-
-        self.finish_handshake()
-        self._potentially_reconnecting = False
-
-        if self.ws:
-            _log.debug("Closing existing voice websocket")
-            await self.ws.close()
-
-        try:
-            self.ws = await self.connect_websocket()
-        except (ConnectionClosed, asyncio.TimeoutError):
-            return False
-        else:
-            return True
+    def wait_until_connected(self, timeout: Optional[float] = 30.0) -> bool:
+        self._connection.wait(timeout)
+        return self._connection.is_connected()
 
     @property
     def latency(self) -> float:
@@ -442,8 +320,8 @@ class VoiceClient(VoiceProtocol):
 
         .. versionadded:: 1.4
         """
-        ws = self.ws
-        return float("inf") if not ws else ws.latency
+        ws = self._connection.ws
+        return float('inf') if not ws else ws.latency
 
     @property
     def average_latency(self) -> float:
@@ -451,72 +329,19 @@ class VoiceClient(VoiceProtocol):
 
         .. versionadded:: 1.4
         """
-        ws = self.ws
-        return float("inf") if not ws else ws.average_latency
-
-    async def poll_voice_ws(self, reconnect: bool) -> None:
-        backoff = ExponentialBackoff()
-        while True:
-            try:
-                await self.ws.poll_event()
-            except (ConnectionClosed, asyncio.TimeoutError) as exc:
-                if isinstance(exc, ConnectionClosed):
-                    # The following close codes are undocumented so I will document them here.
-                    # 1000 - normal closure (obviously)
-                    # 4014 - voice channel has been deleted.
-                    # 4015 - voice server has crashed
-                    if exc.code in (1000, 4015):
-                        _log.info('Disconnecting from voice normally, close code %d.', exc.code)
-                        await self.disconnect()
-                        break
-                    if exc.code == 4014:
-                        _log.info('Disconnected from voice by force... potentially reconnecting.')
-                        successful = await self.potential_reconnect()
-                        if not successful:
-                            _log.info('Reconnect was unsuccessful, disconnecting from voice normally...')
-                            await self.disconnect()
-                            break
-                        else:
-                            continue
-
-                if not reconnect:
-                    await self.disconnect()
-                    raise
-
-                retry = backoff.delay()
-                _log.exception('Disconnected from voice... Reconnecting in %.2fs.', retry)
-                self._connected.clear()
-                await asyncio.sleep(retry)
-                await self.voice_disconnect()
-                try:
-                    await self.connect(reconnect=True, timeout=self.timeout)
-                except asyncio.TimeoutError:
-                    # at this point we've retried 5 times... let's continue the loop.
-                    _log.warning('Could not connect to voice... Retrying...')
-                    continue
+        ws = self._connection.ws
+        return float('inf') if not ws else ws.average_latency
 
     async def disconnect(self, *, force: bool = False) -> None:
         """|coro|
 
         Disconnects this voice client from voice.
         """
-        if not force and not self.is_connected():
-            return
-
         self.stop()
-        self._connected.clear()
+        await self._connection.disconnect(force=force, wait=True)
+        self.cleanup()
 
-        try:
-            if self.ws:
-                await self.ws.close()
-
-            await self.voice_disconnect()
-        finally:
-            self.cleanup()
-            if self.socket:
-                self.socket.close()
-
-    async def move_to(self, channel: Optional[abc.Snowflake]) -> None:
+    async def move_to(self, channel: Optional[abc.Snowflake], *, timeout: Optional[float] = 30.0) -> None:
         """|coro|
 
         Moves you to a different voice channel.
@@ -525,12 +350,21 @@ class VoiceClient(VoiceProtocol):
         -----------
         channel: Optional[:class:`abc.Snowflake`]
             The channel to move to. Must be a voice channel.
+        timeout: Optional[:class:`float`]
+            How long to wait for the move to complete.
+
+            .. versionadded:: 2.4
+
+        Raises
+        -------
+        asyncio.TimeoutError
+            The move did not complete in time, but may still be ongoing.
         """
-        await self.channel.guild.change_voice_state(channel=channel)
+        await self._connection.move_to(channel, timeout)
 
     def is_connected(self) -> bool:
         """Indicates if the voice client is connected to voice."""
-        return self._connected.is_set()
+        return self._connection.is_connected()
 
     # audio related
 
@@ -547,7 +381,21 @@ class VoiceClient(VoiceProtocol):
         encrypt_packet = getattr(self, '_encrypt_' + self.mode)
         return encrypt_packet(header, data)
 
+    def _encrypt_aead_xchacha20_poly1305_rtpsize(self, header: bytes, data) -> bytes:
+        # Esentially the same as _lite
+        # Uses an incrementing 32-bit integer which is appended to the payload
+        # The only other difference is we require AEAD with Additional Authenticated Data (the header)
+        box = nacl.secret.Aead(bytes(self.secret_key))
+        nonce = bytearray(24)
+
+        nonce[:4] = struct.pack('>I', self._incr_nonce)
+        self.checked_add('_incr_nonce', 1, 4294967295)
+
+        return header + box.encrypt(bytes(data), bytes(header), bytes(nonce)).ciphertext + nonce[:4]
+
     def _encrypt_xsalsa20_poly1305(self, header: bytes, data) -> bytes:
+        # Deprecated. Removal: 18th Nov 2024. See:
+        # https://discord.com/developers/docs/topics/voice-connections#transport-encryption-modes
         box = nacl.secret.SecretBox(bytes(self.secret_key))
         nonce = bytearray(24)
         nonce[:12] = header
@@ -555,21 +403,36 @@ class VoiceClient(VoiceProtocol):
         return header + box.encrypt(bytes(data), bytes(nonce)).ciphertext
 
     def _encrypt_xsalsa20_poly1305_suffix(self, header: bytes, data) -> bytes:
+        # Deprecated. Removal: 18th Nov 2024. See:
+        # https://discord.com/developers/docs/topics/voice-connections#transport-encryption-modes
         box = nacl.secret.SecretBox(bytes(self.secret_key))
         nonce = nacl.utils.random(nacl.secret.SecretBox.NONCE_SIZE)
 
         return header + box.encrypt(bytes(data), nonce).ciphertext + nonce
 
     def _encrypt_xsalsa20_poly1305_lite(self, header: bytes, data) -> bytes:
+        # Deprecated. Removal: 18th Nov 2024. See:
+        # https://discord.com/developers/docs/topics/voice-connections#transport-encryption-modes
         box = nacl.secret.SecretBox(bytes(self.secret_key))
         nonce = bytearray(24)
 
-        nonce[:4] = struct.pack('>I', self._lite_nonce)
-        self.checked_add('_lite_nonce', 1, 4294967295)
+        nonce[:4] = struct.pack('>I', self._incr_nonce)
+        self.checked_add('_incr_nonce', 1, 4294967295)
 
         return header + box.encrypt(bytes(data), bytes(nonce)).ciphertext + nonce[:4]
 
-    def play(self, source: AudioSource, *, after: Optional[Callable[[Optional[Exception]], Any]] = None) -> None:
+    def play(
+        self,
+        source: AudioSource,
+        *,
+        after: Optional[Callable[[Optional[Exception]], Any]] = None,
+        application: APPLICATION_CTL = 'audio',
+        bitrate: int = 128,
+        fec: bool = True,
+        expected_packet_loss: float = 0.15,
+        bandwidth: BAND_CTL = 'full',
+        signal_type: SIGNAL_CTL = 'auto',
+    ) -> None:
         """Plays an :class:`AudioSource`.
 
         The finalizer, ``after`` is called after the source has been exhausted
@@ -579,9 +442,15 @@ class VoiceClient(VoiceProtocol):
         caught and the audio player is then stopped.  If no after callback is
         passed, any caught exception will be logged using the library logger.
 
+        Extra parameters may be passed to the internal opus encoder if a PCM based
+        source is used.  Otherwise, they are ignored.
+
         .. versionchanged:: 2.0
             Instead of writing to ``sys.stderr``, the library's logger is used.
 
+        .. versionchanged:: 2.4
+            Added encoder parameters as keyword arguments.
+
         Parameters
         -----------
         source: :class:`AudioSource`
@@ -590,6 +459,27 @@ class VoiceClient(VoiceProtocol):
             The finalizer that is called after the stream is exhausted.
             This function must have a single parameter, ``error``, that
             denotes an optional exception that was raised during playing.
+        application: :class:`str`
+            Configures the encoder's intended application.  Can be one of:
+            ``'audio'``, ``'voip'``, ``'lowdelay'``.
+            Defaults to ``'audio'``.
+        bitrate: :class:`int`
+            Configures the bitrate in the encoder.  Can be between ``16`` and ``512``.
+            Defaults to ``128``.
+        fec: :class:`bool`
+            Configures the encoder's use of inband forward error correction.
+            Defaults to ``True``.
+        expected_packet_loss: :class:`float`
+            Configures the encoder's expected packet loss percentage.  Requires FEC.
+            Defaults to ``0.15``.
+        bandwidth: :class:`str`
+            Configures the encoder's bandpass.  Can be one of:
+            ``'narrow'``, ``'medium'``, ``'wide'``, ``'superwide'``, ``'full'``.
+            Defaults to ``'full'``.
+        signal_type: :class:`str`
+            Configures the type of signal being encoded.  Can be one of:
+            ``'auto'``, ``'voice'``, ``'music'``.
+            Defaults to ``'auto'``.
 
         Raises
         -------
@@ -599,6 +489,8 @@ class VoiceClient(VoiceProtocol):
             Source is not a :class:`AudioSource` or after is not a callable.
         OpusNotLoaded
             Source is not opus encoded and opus is not loaded.
+        ValueError
+            An improper value was passed as an encoder parameter.
         """
 
         if not self.is_connected():
@@ -610,8 +502,15 @@ class VoiceClient(VoiceProtocol):
         if not isinstance(source, AudioSource):
             raise TypeError(f'source must be an AudioSource not {source.__class__.__name__}')
 
-        if not self.encoder and not source.is_opus():
-            self.encoder = opus.Encoder()
+        if not source.is_opus():
+            self.encoder = opus.Encoder(
+                application=application,
+                bitrate=bitrate,
+                fec=fec,
+                expected_packet_loss=expected_packet_loss,
+                bandwidth=bandwidth,
+                signal_type=signal_type,
+            )
 
         self._player = AudioPlayer(source, self, after=after)
         self._player.start()
@@ -656,7 +555,7 @@ class VoiceClient(VoiceProtocol):
         if self._player is None:
             raise ValueError('Not playing anything.')
 
-        self._player._set_source(value)
+        self._player.set_source(value)
 
     def send_audio_packet(self, data: bytes, *, encode: bool = True) -> None:
         """Sends an audio packet composed of the data.
@@ -685,8 +584,8 @@ class VoiceClient(VoiceProtocol):
             encoded_data = data
         packet = self._get_voice_packet(encoded_data)
         try:
-            self.socket.sendto(packet, (self.endpoint_ip, self.voice_port))
-        except BlockingIOError:
-            _log.warning('A packet has been dropped (seq: %s, timestamp: %s)', self.sequence, self.timestamp)
+            self._connection.send_packet(packet)
+        except OSError:
+            _log.debug('A packet has been dropped (seq: %s, timestamp: %s)', self.sequence, self.timestamp)
 
         self.checked_add('timestamp', opus.Encoder.SAMPLES_PER_FRAME, 4294967295)
