@@ -5,7 +5,8 @@ from discord.ext import commands
 
 intents = discord.Intents.default()
 
-bot = commands.Bot(command_prefix=commands.when_mentioned, description="Nothing to see here!", intents=intents)
+bot = commands.Bot(command_prefix=commands.when_mentioned, description='Nothing to see here!', intents=intents)
+
 
 # the `hidden` keyword argument hides it from the help command.
 @bot.group(hidden=True)
