@@ -7,6 +7,9 @@ from urllib.parse import quote_plus
 
 
 class GoogleBot(commands.Bot):
+    # Suppress error on the User attribute being None since it fills up later
+    user: discord.ClientUser
+
     def __init__(self):
         intents = discord.Intents.default()
         intents.message_content = True
